package Tatsumaki::Template;
use Any::Moose;

sub render_file;
sub include_path;

1;
